adjustPeaks modifies the mean and SD of the peak width distribution
for each condition, so that they become equivalent to the condition
with widest peaks. See details.
adjustPeaks(x, adjust, sampleid, logscale = TRUE)RangedDataList indicating the binding sites for each sample/experiment.sampleid should take the same value for samples
obtained under different conditions, as this is used to detect
the samples to be used for Procrustes adjustment.TRUE the mean and SD are matched for
log width, otherwise the original widths are used. Working in log
scale can help reduce the effect of outliers (e.g. an usually long
binding site).RangedDataList object with adjusted widths.
x contains
the binding sites for a different sample. The start, end and
chrosomome of each binding sites should be accessed via start,
end and space. procrustesAdj for an alternative, more general, adjustment
based on Procrustes. distGPS for computing distances,
mds to create MDS-oriented objects.
#See examples in help(procrustesAdj)
Run the code above in your browser using DataLab